.. _series-docs:

======
Series
======

The series module implements series expansions as a function and many related
functions.

Contents
========

.. toctree::
    :maxdepth: 2

    series.rst
    sequences.rst
    fourier.rst
    formal.rst
    limitseq.rst
